@@ -127,7 +127,6 @@ tp_add_dispatch_operation_context_dispose (GObject *object)
 
   if (self->channels != NULL)
     {
-      g_ptr_array_foreach (self->channels, (GFunc) g_object_unref, NULL);
       g_ptr_array_unref (self->channels);
       self->channels = NULL;
     }
@@ -202,7 +201,6 @@ tp_add_dispatch_operation_context_set_property (GObject *object,
 
       case PROP_CHANNELS:
         self->channels = g_value_dup_boxed (value);
-        g_ptr_array_foreach (self->channels, (GFunc) g_object_ref, NULL);
         break;
 
       case PROP_DISPATCH_OPERATION:
